==> fixed_text_link_formatter-8.x-1.0.tar.gz: fixed_text_link_formatter/src/Plugin/Field/FieldFormatter/FixedTextLink.php <==
<?php

namespace Drupal\fixed_text_link_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\link\Plugin\Field\FieldFormatter\LinkFormatter;

/**
 * Plugin implementation of the 'link' formatter.
 *
 * @FieldFormatter(
 *   id = "fixed_text_link",
 *   label = @Translation("Link with fixed text"),
 *   field_types = {
 *     "link"
 *   }
 * )
 */
class FixedTextLink extends LinkFormatter {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'trim_length' => '',
      'link_text' => t('View website'),
    ) + parent::defaultSettings();
  }

  public function settingsForm(array $parentForm, FormStateInterface $form_state) {
    $parentForm = parent::settingsForm($parentForm, $form_state);
    $settings = $this->getSettings();

    unset($parentForm['trim_length']);
    unset($parentForm['url_only']);
    unset($parentForm['url_plain']);

    $form['link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link text'),
      '#default_value' => $settings['link_text'],
      '#required' => TRUE,
    ];

    return $form + $parentForm;
  }

  public function settingsSummary() {
    $settings = $this->getSettings();

    $summary[] = $this->t('Link text: @text', ['@text' => $settings['link_text']]);
    if (!empty($settings['rel'])) {
      $summary[] = $this->t('Add rel="@rel"', ['@rel' => $settings['rel']]);
    }
    if (!empty($settings['target'])) {
      $summary[] = $this->t('Open link in new window');
    }

    return $summary;
  }

  public function viewElements(FieldItemListInterface $items, $langcode) {
    $settings = $this->getSettings();

    foreach ($items as $item) {
      $item->set('title', $settings['link_text']);
    }

    return parent::viewElements($items, $langcode);
  }
}

==> fixed_text_link_formatter-8.x-1.2.tar.gz: fixed_text_link_formatter/src/Plugin/Field/FieldFormatter/FixedTextLink.php <==
<?php

namespace Drupal\fixed_text_link_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\link\Plugin\Field\FieldFormatter\LinkFormatter;

/**
 * Plugin implementation of the 'link' formatter.
 *
 * @FieldFormatter(
 *   id = "fixed_text_link",
 *   label = @Translation("Link with fixed text"),
 *   field_types = {
 *     "link"
 *   }
 * )
 */
class FixedTextLink extends LinkFormatter {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'trim_length' => '',
      'link_text' => 'View website',
      'allow_override' => FALSE,
    ) + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $parentForm, FormStateInterface $form_state) {
    $parentForm = parent::settingsForm($parentForm, $form_state);

    unset($parentForm['trim_length']);
    unset($parentForm['url_only']);
    unset($parentForm['url_plain']);

    $form['link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link text'),
      '#default_value' => $this->getLinkText(),
      '#required' => TRUE,
    ];

    $form['allow_override'] = [
      '#type' => 'checkbox',
      '#title' => $this->t("Allow the title to be overridden"),
      '#default_value' => $this->getSetting('allow_override'),
    ];

    return $form + $parentForm;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();

    $summary[] = $this->t('Link text: @text', ['@text' => $this->getTranslatedLinkText()]);
    if (!empty($settings['rel'])) {
      $summary[] = $this->t('Add rel="@rel"', ['@rel' => $settings['rel']]);
    }
    if (!empty($settings['target'])) {
      $summary[] = $this->t('Open link in new window');
    }

    if ($this->getSetting('allow_override')) {
      $summary[] = $this->t('Link text can be overridden');
    }

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    /** @var \Drupal\link\Plugin\Field\FieldType\LinkItem $item */
    foreach ($items as $item) {
      $allowOverride = (bool) $this->getSetting('allow_override');
      $shouldOverride = $allowOverride && !empty($item->get('title'));
      if (!$allowOverride || ($shouldOverride)) {
        $item->set('title', $this->getTranslatedLinkText());
      }
    }

    return parent::viewElements($items, $langcode);
  }

  /**
   * @return mixed
   */
  private function getLinkText() {
    return $this->getSettings()['link_text'];
  }

  /**
   * @return mixed
   */
  private function getTranslatedLinkText() {
    return $this->t($this->getLinkText(), [], ['context' => 'User entered link title']);
  }
}
